#include <Servo.h>
Servo servo3;
Servo servo5;

const int pwmPin3 = 3;
const int pwmPin5 = 5;
const int sensorPH = A0; // Pin para el sensor de pH
const int TdsSensorPin = A1; // Pin para el sensor de TDS

char val;
String grados;
int angulo;
int buffer_tds[10], temp1;
unsigned long int avgval_ADC;

void setup() {
  Serial.begin(9600); // Inicializa comunicación serial para enviar datos via Bluetooth
  pinMode(pwmPin3, OUTPUT);
  pinMode(pwmPin5, OUTPUT);
  pinMode(sensorPH, INPUT);
  pinMode(TdsSensorPin, INPUT);

  servo3.attach(pwmPin3);
  servo5.attach(pwmPin5);
}

void loop() {
  if (Serial.available()) {
    val = Serial.read();
    if (isDigit(val)) { grados += (char)val; }
    if (val == '\n') {
      angulo = grados.toInt();
      Serial.println(angulo);

      if (angulo == 0 || angulo == 90 || angulo == 180) {
        servo3.write(angulo);
      }
      if (angulo == 91 || angulo == 181) {
        servo5.write(angulo - 90);
      }

      grados = "";
    }
  }

  // Leer el valor del sensor de pH
  int phValue = analogRead(sensorPH);
  // Convertir el valor de pH a voltaje (esto depende de la calibración)
  float voltage = phValue * (5.0 / 1024.0); // El valor de 5V se ajusta al rango de lectura del sensor

  // Calcular el valor de pH (esto se puede ajustar según la calibración del sensor)
  float ph = 7 + ((2.5 - voltage) / 0.18);

  // Leer y procesar los datos del sensor de TDS
  for (int i = 0; i < 10; i++) {
    buffer_tds[i] = analogRead(TdsSensorPin);
    delay(30);
  }

  // Ordenar y calcular el promedio de los valores de TDS
  for (int i = 0; i < 9; i++) {
    for (int j = i + 1; j < 10; j++) {
      if (buffer_tds[i] > buffer_tds[j]) {
        temp1 = buffer_tds[i];
        buffer_tds[i] = buffer_tds[j];
        buffer_tds[j] = temp1;
      }
    }
  }

  avgval_ADC = 0;
  for (int i = 2; i < 8; i++)
    avgval_ADC += buffer_tds[i];

  float voltage_value = (float)avgval_ADC * 5.0 / 1024.0 / 6;
  float TDS = (133.42 / voltage_value * voltage_value - 255.86 * voltage_value + 857.39) * 0.5;

  // Enviar los datos de pH y TDS por Bluetooth (Serial Monitor)
  Serial.print("pH: ");
  Serial.print(ph);
  Serial.print(";");
  
  Serial.print(" TDS: ");
  Serial.print(TDS);
  Serial.println(";");

  delay(1000);
}
